use indicatif::ProgressBar;

pub trait ProgressTracker {
    fn inc_progress(&mut self, delta_progress: u64);
    fn set_current(&mut self, current_progress: u64);
    fn set_max_size(&mut self, max_size: u64);
}

impl ProgressTracker for ProgressBar {
    #[inline]
    fn set_max_size(&mut self, max_size: u64) {
        self.set_length(max_size);
    }

    #[inline]
    fn inc_progress(&mut self, delta_progress: u64) {
        self.inc(delta_progress);
    }

    #[inline]
    fn set_current(&mut self, current_progress: u64) {
        self.set_position(current_progress);
    }
}

/// No-operation progress tracker.
impl ProgressTracker for () {
    #[inline]
    fn set_max_size(&mut self, _max_size: u64) {
        // nop
    }

    #[inline]
    fn inc_progress(&mut self, _delta_progress: u64) {
        // nop
    }

    #[inline]
    fn set_current(&mut self, _current_progress: u64) {
        // nop
    }
}
