/*
This file is part of Yama.

Yama is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Yama is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Yama.  If not, see <https://www.gnu.org/licenses/>.
*/

use std::fmt::Write;

pub fn bytes_to_hexstring(chunkid: &[u8]) -> String {
    let mut s = String::with_capacity(chunkid.len() * 2);
    for &byte in chunkid.iter() {
        write!(&mut s, "{:02x}", byte).expect("Unable to write");
    }
    s
}

pub fn get_number_of_workers(first_try_env_name: &str) -> u8 {
    let from_env_var = std::env::var(first_try_env_name)
        .ok()
        .or_else(|| std::env::var("YAMA_WORKERS").ok());
    if let Some(from_env_var) = from_env_var {
        from_env_var
            .parse()
            .expect("Number of workers should be an integer from 1 to 255.")
    } else {
        let number = num_cpus::get();
        if number > u8::MAX.into() {
            u8::MAX
        } else {
            number as u8
        }
    }
}
